@@ -7,7 +7,7 @@
 # http://search.cpan.org/dist/Devel-NYTProf/
 #
 ###########################################################
-# $Id: Util.pm 719 2009-03-24 09:21:49Z tim.bunce $
+# $Id: Util.pm 774 2009-06-18 20:44:25Z tim.bunce $
 ###########################################################
 package Devel::NYTProf::Util;
 
@@ -38,9 +38,9 @@ use base qw'Exporter';
 use Carp;
 use Cwd qw(getcwd);
 use List::Util qw(sum);
-use UNIVERSAL qw( isa can VERSION );
+#use UNIVERSAL qw( isa can VERSION );
 
-our $VERSION = '2.09';
+our $VERSION = '2.10';
 
 our @EXPORT_OK = qw(
     fmt_float
@@ -223,6 +223,12 @@ sub html_safe_filename {
     # remove any leading or trailing '-' chars
     $fname =~ s{^-}{};
     $fname =~ s{-$}{};
+    if($^O eq 'VMS'){
+        # ODS-2 is limited to 39.39 chars (39 filename, 39 extension)
+	# Reader.pm appends -LEVEL onto html safe filename so must
+	# subtract 1 + max length of (sub block line), so 6.
+        $fname = substr($fname,-33);
+    }
     return $fname;
 }
 
